==> reference4-1.0-sources.jar: one/xingyi/reference4/person/server/domain/PersonDebugInfo.java <==
package one.xingyi.reference4.person.server.domain;
//Made by one.xingyi.core.filemaker.CodeDomDebugFileMaker
//Defn one.xingyi.reference4.person.IPersonDefn
public class PersonDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference4.person.IPersonDefn
    IServer:    one.xingyi.reference4.person.server.domain.IPerson
    ServerImpl: one.xingyi.reference4.person.server.domain.Person
    Client:     one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity
    ServComp:   one.xingyi.reference4.person.server.companion.PersonCompanion
    Lens:       Person
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/person, urlPattern={host}/person/{id}, code={host}/person/code)]
Fields: 7
    Field: name
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  name/String
        Lens name  lens_Person_name
        Readonly   true
        Javascript functionlens_Person_name(){returnlens('name');};
        Templated: false
        Deprecated false
    Field: telephone
        ViewType(typeName=one.xingyi.reference4.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference4.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference4.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference4.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference4.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
        Lens path  telephone/TelephoneNumber
        Lens name  lens_Person_telephone
        Readonly   false
        Javascript functionlens_Person_telephone(){returnlens('telephone');};
        Templated: false
        Deprecated false
    Field: age
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=Integer))
        Lens path  age/Integer
        Lens name  lens_Person_age
        Readonly   false
        Javascript functionlens_Person_age(){returnlens('age');};
        Templated: false
        Deprecated false
    Field: line1
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  line1/String
        Lens name  lens_Person_line1
        Readonly   false
        Javascript functionlens_Person_line1(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  line2/String
        Lens name  lens_Person_line2
        Readonly   false
        Javascript functionlens_Person_line2(){returnlens('line2');};
        Templated: false
        Deprecated false
    Field: address
        ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference4.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference4.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
        Lens path  {identity}
        Lens name  lens_Person_address
        Readonly   false
        Javascript functionlens_Person_address(){returnidentityLens();};
        Templated: false
        Deprecated true
    Field: addresses
        ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference4.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference4.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
        Lens path  {itemAsList}
        Lens name  lens_Person_addresses
        Readonly   false
        Javascript functionlens_Person_addresses(){returnitemAsListLens();};
        Templated: false
        Deprecated true
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional[PutDom()]
Create         Optional[CreateDom()]
CreateNoId     Optional[CreateWithoutIdDom(path={host}/person)]
Delete         Optional[DeleteDom()]
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}

==> reference4-1.1-sources.jar: one/xingyi/reference4/person/server/domain/PersonDebugInfo.java <==
package one.xingyi.reference4.person.server.domain;
//Made by one.xingyi.core.filemaker.CodeDomDebugFileMaker
//Defn one.xingyi.reference4.person.IPersonDefn
public class PersonDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference4.person.IPersonDefn
    IServer:    one.xingyi.reference4.person.server.domain.IPerson
    ServerImpl: one.xingyi.reference4.person.server.domain.Person
    Client:     one.xingyi.reference4.person.client.entitydefn.IPersonClientEntity
    ServComp:   one.xingyi.reference4.person.server.companion.PersonCompanion
    Lens:       Person
bookmarkAndUrl Optional[BookmarkCodeAndUrlPattern(bookmark=/person, urlPattern={host}/person/{id}, code={host}/person/code)]
Fields: 7
    Field: name
        StringPrimitiveType()
        Lens path  name/String
        Lens name  lens_Person_name
        Readonly   true
        Javascript functionlens_Person_name(){returnlens('name');};
        Templated: false
        Deprecated false
    Field: telephone
        ViewType(typeName=one.xingyi.reference4.telephone.ITelephoneNumberViewDefn, forEntity=one.xingyi.reference4.telephone.server.domain.ITelephoneNumber, forView=one.xingyi.reference4.telephone.client.view.TelephoneNumberView, viewCompanion=one.xingyi.reference4.telephone.client.viewcompanion.TelephoneNumberViewCompanion, serverCompanion=one.xingyi.reference4.telephone.server.companion.TelephoneNumberCompanion, entityNameForLens=TelephoneNumber)
        Lens path  telephone/TelephoneNumber
        Lens name  lens_Person_telephone
        Readonly   false
        Javascript functionlens_Person_telephone(){returnlens('telephone');};
        Templated: false
        Deprecated false
    Field: age
        IntegerPrimitiveType()
        Lens path  age/Integer
        Lens name  lens_Person_age
        Readonly   false
        Javascript functionlens_Person_age(){returnlens('age');};
        Templated: false
        Deprecated false
    Field: line1
        StringPrimitiveType()
        Lens path  line1/String
        Lens name  lens_Person_line1
        Readonly   false
        Javascript functionlens_Person_line1(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        StringPrimitiveType()
        Lens path  line2/String
        Lens name  lens_Person_line2
        Readonly   false
        Javascript functionlens_Person_line2(){returnlens('line2');};
        Templated: false
        Deprecated false
    Field: address
        ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address)
        Lens path  {identity}
        Lens name  lens_Person_address
        Readonly   false
        Javascript functionlens_Person_address(){returnidentityLens();};
        Templated: false
        Deprecated true
    Field: addresses
        ListType(fullTypeName=one.xingyi.core.client.IResourceList<one.xingyi.reference4.address.IAddressLine12ViewDefn>, nested=ViewType(typeName=one.xingyi.reference4.address.IAddressLine12ViewDefn, forEntity=one.xingyi.reference4.address.server.domain.IAddress, forView=one.xingyi.reference4.address.client.view.AddressLine12View, viewCompanion=one.xingyi.reference4.address.client.viewcompanion.AddressLine12ViewCompanion, serverCompanion=one.xingyi.reference4.address.server.companion.AddressCompanion, entityNameForLens=Address), companionName=PackageAndClassName(packageName=one.xingyi.reference4.address.server.companion, className=AddressCompanion), entityNameForLens=Address)
        Lens path  {itemAsList}
        Lens name  lens_Person_addresses
        Readonly   false
        Javascript functionlens_Person_addresses(){returnitemAsListLens();};
        Templated: false
        Deprecated true
Get            Optional[GetDom()]
optionalGet    Optional[OptionalGetDom()]
Put            Optional[PutDom()]
Create         Optional[CreateDom()]
CreateNoId     Optional[CreateWithoutIdDom(path={host}/person)]
Delete         Optional[DeleteDom()]
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}
